// (C) 2021-2024 GoodData Corporation
import { DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT, MAX_VISUALIZATION_HEIGHT, MIN_VISUALIZATION_HEIGHT, MIDDLE_VISUALIZATION_HEIGHT, } from "../constants.js";
import { addIntersectionFiltersToInsight, modifyBucketsAttributesForDrillDown } from "../drillDownUtil.js";
export class BaseChartDescriptor {
    getSizeInfo(_insight, layoutDescriptor, settings) {
        return {
            width: {
                default: settings.enableDashboardFlexibleLayout ? 4 : 6,
                min: 2,
                max: layoutDescriptor.gridColumnsCount,
            },
            height: {
                default: this.getDefaultHeight(settings.enableKDWidgetCustomHeight),
                min: this.getMinHeight(settings.enableKDWidgetCustomHeight),
                max: this.getMaxHeight(settings.enableKDWidgetCustomHeight),
            },
        };
    }
    getDefaultHeight(enableCustomHeight) {
        if (!enableCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        return MIDDLE_VISUALIZATION_HEIGHT;
    }
    getMinHeight(enableCustomHeight) {
        if (!enableCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        return MIN_VISUALIZATION_HEIGHT;
    }
    getMaxHeight(enableCustomHeight) {
        if (!enableCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        return MAX_VISUALIZATION_HEIGHT;
    }
    applyDrillDown(insight, drillDownContext, backendSupportsElementUris, enableDuplicatedLabelValuesInAttributeFilter) {
        const intersection = drillDownContext.event.drillContext.intersection;
        const withFilters = addIntersectionFiltersToInsight(insight, intersection, backendSupportsElementUris, enableDuplicatedLabelValuesInAttributeFilter);
        return modifyBucketsAttributesForDrillDown(withFilters, drillDownContext.drillDefinition);
    }
}
//# sourceMappingURL=BaseChartDescriptor.js.map